@@ -88,7 +88,7 @@ class _ResImageNet(nn.Module):
             return
 
         self.features = nn.Sequential(OrderedDict([
-            ('conv0', nn.Conv2d(in_channels=3, out_channels=num_init_features, 
+            ('conv0', nn.Conv2d(in_channels=1, out_channels=num_init_features, 
                                 kernel_size=7, padding=3, bias=False)),
             ('norm0', nn.BatchNorm2d(num_init_features)),
             ('relu', nn.ReLU(inplace=True)),
@@ -114,7 +114,7 @@ class _ResImageNet(nn.Module):
             num_features = num_features // 2
         
         self.features.add_module('norm', nn.BatchNorm2d(num_features))
-        self.features.add_module('conv3x3', nn.Conv2d(in_channels=num_features, out_channels=3, 
+        self.features.add_module('conv3x3', nn.Conv2d(in_channels=num_features, out_channels=1, 
                                                     kernel_size=3, stride=1, padding=1, bias=False))
         self.features.add_module('sigm', nn.Sigmoid())
         # Init weights before start learning
@@ -143,16 +143,19 @@ class ResImageDataset(Dataset):
         return len(self.raw)
 
     def imageTransform(self, raw_image, inpainted_image):
-        # Gray to RGB conversion
-        if len(raw_image.shape) < 3:
-            raw_image = color.gray2rgb(raw_image)
-        if len(inpainted_image.shape) < 3:
-            inpainted_image = color.gray2rgb(inpainted_image)
-        # RGBA to RGB conversion
-        if raw_image.shape[2] > 3:
-            raw_image = color.rgba2rgb(raw_image)
-        if inpainted_image.shape[2] > 3:
-            inpainted_image = color.rgba2rgb(inpainted_image)
+        # RGBA/RGB to Gray conversion
+        if len(raw_image.shape) > 2:
+            if raw_image.shape[2] > 3:
+                raw_image = color.rgba2rgb(raw_image)
+                raw_image = color.rgb2gray(raw_image)
+            elif raw_image.shape[2] == 3:
+                raw_image = color.rgb2gray(raw_image)
+        if len(inpainted_image.shape) > 2:
+            if inpainted_image.shape[2] > 3:
+                inpainted_image = color.rgba2rgb(inpainted_image)
+                inpainted_image = color.rgb2gray(inpainted_image)
+            elif inpainted_image.shape[2] == 3:
+                inpainted_image = color.rgb2gray(inpainted_image)
 
         if raw_image.shape != inpainted_image.shape:
             print("Image size problem (raw shape {} and inpainted {}): resizing raw to inpainted.".format(raw_image.shape, inpainted_image.shape))
@@ -265,6 +268,20 @@ class ResImageNet():
             raw_image = io.imread(os.path.join(image_dir, "raw", raw[i]))
             inpainted_image = io.imread(os.path.join(image_dir, "inpainted", inpainted[i]))
 
+            # RGBA/RGB to Gray conversion
+            if len(raw_image.shape) > 2:
+                if raw_image.shape[2] > 3:
+                    raw_image = color.rgba2rgb(raw_image)
+                    raw_image = color.rgb2gray(raw_image)
+                elif raw_image.shape[2] == 3:
+                    raw_image = color.rgb2gray(raw_image)
+            if len(inpainted_image.shape) > 2:
+                if inpainted_image.shape[2] > 3:
+                    inpainted_image = color.rgba2rgb(inpainted_image)
+                    inpainted_image = color.rgb2gray(inpainted_image)
+                elif inpainted_image.shape[2] == 3:
+                    inpainted_image = color.rgb2gray(inpainted_image)
+
             w = raw_image.shape[0]
             w = (w // 4) * 4
             h = raw_image.shape[1]
